.. pynbody reference main index


.. _reference :

Pynbody reference documentation
===============================

The reference documentation for pynbody is largely generated automatically
from the source code. It is split into the following sections:

.. toctree::
   :maxdepth: 1

   The core modules that allow you to load and manipulate data <essentials>
   The next-level modules that handle SPH and other processing tasks <convenience>
   The derived array system <derived>
   Scientific analysis routines <analysis>
   Scientific plotting routines <plot>
